import { IssueOrPullRequest, Project, ProjectColumn, PullRequest } from "./github";
export declare type OnChangeHandler = (item: IssueOrPullRequest) => void;
export interface ActionExecuteInfo {
}
export interface IAction {
    summary: string;
    onChanged(handler: OnChangeHandler): void;
}
export interface IActionImplementation extends IAction {
    execute(info: ActionExecuteInfo): Promise<void>;
}
export declare abstract class BaseAction implements IActionImplementation {
    readonly abstract summary: string;
    protected beforeChangeHandlers: OnChangeHandler[];
    protected afterChangeHandlers: OnChangeHandler[];
    onChanged(handler: OnChangeHandler): void;
    onBeforeChange(handler: OnChangeHandler): void;
    protected fireOnBeforeChange(issue: IssueOrPullRequest): Promise<void>;
    protected fireOnChanged(issue: IssueOrPullRequest): Promise<void>;
    abstract execute(info: ActionExecuteInfo): Promise<void>;
}
export declare abstract class BaseIssueAction extends BaseAction {
    readonly issue: IssueOrPullRequest;
    constructor(issue: IssueOrPullRequest);
    protected fireOnBeforeChange(): Promise<void>;
    protected fireOnChanged(): Promise<void>;
}
export declare namespace PullRequests {
    abstract class Base extends BaseAction {
        readonly pr: PullRequest;
        constructor(pr: PullRequest);
    }
    class Merge extends Base {
        readonly summary: string;
        execute(_info: ActionExecuteInfo): Promise<void>;
        private getMergeOptions();
    }
}
export declare namespace Labels {
    abstract class Base extends BaseIssueAction {
        readonly labels: ReadonlyArray<string>;
        constructor(issue: IssueOrPullRequest, labels: ReadonlyArray<string>);
    }
    class Add extends Base {
        readonly summary: string;
        execute(_info: ActionExecuteInfo): Promise<void>;
    }
    class Remove extends Base {
        readonly summary: string;
        execute(_info: ActionExecuteInfo): Promise<void>;
    }
    class Set extends Base {
        readonly summary: string;
        execute(_info: ActionExecuteInfo): Promise<void>;
    }
}
export declare namespace Comments {
    abstract class Base extends BaseIssueAction {
        readonly slug: string;
        constructor(issue: IssueOrPullRequest, slug: string);
    }
    class Add extends Base {
        readonly body: string;
        constructor(issue: IssueOrPullRequest, slug: string, body: string);
        readonly summary: string;
        execute(_info: ActionExecuteInfo): Promise<void>;
    }
}
export declare namespace Assignees {
    abstract class Base extends BaseIssueAction {
        readonly assignees: ReadonlyArray<string>;
        constructor(issue: IssueOrPullRequest, assignees: ReadonlyArray<string>);
    }
    class Add extends Base {
        readonly summary: string;
        execute(_info: ActionExecuteInfo): Promise<void>;
    }
}
export declare namespace Issues {
    class SetColumn extends BaseIssueAction {
        readonly project: Project;
        readonly column: ProjectColumn | undefined;
        readonly summary: string;
        constructor(issue: IssueOrPullRequest, project: Project, column: ProjectColumn | undefined);
        execute(_info: ActionExecuteInfo): Promise<void>;
    }
    class Lock extends BaseIssueAction {
        readonly summary: string;
        execute(_info: ActionExecuteInfo): Promise<void>;
    }
    class Unlock extends BaseIssueAction {
        readonly summary: string;
        execute(_info: ActionExecuteInfo): Promise<void>;
    }
    class Close extends BaseIssueAction {
        readonly summary: string;
        execute(_info: ActionExecuteInfo): Promise<void>;
    }
    class Reopen extends BaseIssueAction {
        readonly summary: string;
        execute(_info: ActionExecuteInfo): Promise<void>;
    }
}
