"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs-extra");
const path_1 = require("path");
function createCache(cacheRoot) {
    function getFilename(key) {
        return path_1.join(cacheRoot, key);
    }
    async function save(content, key, timestamp) {
        const filePath = getFilename(key);
        await fs.mkdirp(path_1.dirname(filePath));
        const withTime = { timestamp: timestamp.toUTCString(), content };
        await fs.writeFile(filePath, JSON.stringify(withTime), { encoding: "utf8" });
    }
    async function load(key) {
        const path = getFilename(key);
        if (await fs.pathExists(path)) {
            const result = JSON.parse(await fs.readFile(path, "utf8"));
            result.exists = true;
            return result;
        }
        else {
            return {
                exists: false,
            };
        }
    }
    return {
        save,
        load,
    };
}
exports.createCache = createCache;
//# sourceMappingURL=cache.js.map