import { Issue, IssueComment, IssueOrPullRequest, ProjectCard, ProjectColumn, PullRequest } from "./github";
import * as api from "./github-api";
import { Query } from "./options";
export interface IssuePageFetchResult {
    issues: api.Issue[];
    fetchMore?(): Promise<IssuePageFetchResult>;
}
export declare function initialize(_oauthToken: string): void;
export declare function getMyLogin(): Promise<string>;
export declare function addLabels(issue: Issue, labels: ReadonlyArray<string>): Promise<void>;
export declare function removeLabels(issue: Issue, labels: ReadonlyArray<string>): Promise<void>;
export declare function setLabels(issue: Issue, labels: ReadonlyArray<string>): Promise<void>;
export declare function lockIssue(issue: Issue): Promise<void>;
export declare function unlockIssue(issue: Issue): Promise<void>;
export declare function closeIssue(issue: Issue): Promise<void>;
export declare function reopenIssue(issue: Issue): Promise<void>;
export declare function addComment(issue: Issue, body: string): Promise<void>;
export declare function editComment(comment: IssueComment, body: string): Promise<void>;
export interface IssuePageResult {
    page: api.Issue[];
    next?(): Promise<IssuePageResult>;
}
export declare function fetchAllIssuesAndPRsRaw(repo: api.RepoReference): Promise<IssuePageResult>;
export declare function fetchChangedIssuesRaw(repo: api.RepoReference): Promise<api.Issue[]>;
export declare function runQuery(q: Query, callback: (item: PullRequest | Issue) => Promise<void>): Promise<void>;
export declare function fetchChangedPRsRaw(repo: api.RepoReference): Promise<api.PullRequestFromList[]>;
export declare function fetchProjectColumns(projectId: number): Promise<api.ProjectColumn[]>;
export declare function fetchProjectColumnCards(columnId: number): Promise<api.ProjectColumnCard[]>;
export declare function createProjectCard(columnId: number, issue: IssueOrPullRequest): Promise<void>;
export declare function moveProjectCard(card: ProjectCard, targetColumn: ProjectColumn): Promise<void>;
export declare function deleteProjectCard(card: ProjectCard): Promise<void>;
export declare function fetchIssueComments(issue: Issue): Promise<api.IssueComment[]>;
export declare function fetchPRCommits(issue: PullRequest): Promise<api.PullRequestCommit[]>;
export declare function fetchPRFiles(issue: PullRequest): Promise<api.PullRequestFile[]>;
export declare function fetchIssueCommentReactions(repo: api.RepoReference, commentId: number): Promise<api.Reaction[]>;
export declare function fetchPR(repo: api.RepoReference, number: number | string): Promise<api.PullRequest>;
export interface MergePrOptions {
    readonly title: string;
    readonly message: string;
    readonly sha: string;
}
export declare function mergePR(pr: PullRequest, {title, message, sha}: MergePrOptions): Promise<void>;
export declare function fetchIssue(repo: api.RepoReference, number: number | string): Promise<api.Issue>;
export declare function fetchPRReviews(repo: api.RepoReference, number: number): Promise<api.PullRequestReview[]>;
export declare function fetchRefStatusSummary(repo: api.RepoReference, ref: string): Promise<api.CombinedStatus>;
export interface ExecOptions {
    queryString?: {
        [key: string]: string;
    };
    body?: string;
    preview?: string;
}
export declare class ExecError extends Error {
    readonly statusCode: number;
    constructor(message: string, statusCode: number);
}
export declare function exec(method: "GET" | "PUT" | "POST" | "DELETE" | "PATCH", basePath: string, opts?: ExecOptions): Promise<string>;
