"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Actions = require("./action");
exports.Actions = Actions;
const actionRunner_1 = require("./actionRunner");
const cache_1 = require("./cache");
const client = require("./client");
const github_1 = require("./github");
var github_2 = require("./github");
exports.User = github_2.User;
exports.Issue = github_2.Issue;
exports.IssueComment = github_2.IssueComment;
exports.PullRequest = github_2.PullRequest;
exports.Milestone = github_2.Milestone;
exports.Label = github_2.Label;
exports.IssueOrPullRequest = github_2.IssueOrPullRequest;
exports.Project = github_2.Project;
exports.ProjectCard = github_2.ProjectCard;
exports.ProjectColumn = github_2.ProjectColumn;
process.on("unhandledRejection", (err) => {
    console.error(err);
});
async function runRulesOn(item, setup) {
    if (setup.rules.issues && !item.isPullRequest) {
        for (const ruleName of Object.keys(setup.rules.issues)) {
            await runRule(item, setup.rules.issues[ruleName], ruleName);
        }
    }
    if (setup.rules.pullRequests && item.isPullRequest) {
        for (const ruleName of Object.keys(setup.rules.pullRequests)) {
            await runRule(item, setup.rules.pullRequests[ruleName], ruleName);
        }
    }
    if (setup.rules.issuesAndPullRequests) {
        for (const ruleName of Object.keys(setup.rules.issuesAndPullRequests)) {
            await runRule(item, setup.rules.issuesAndPullRequests[ruleName], ruleName);
        }
    }
}
async function runRule(issue, rule, name) {
    try {
        const result = rule(issue);
        if (result !== undefined) {
            await result;
        }
    }
    catch (e) {
        console.error(`Rule ${name} encountered exception running on ${issue.html_url}`);
        console.error(e.stack);
    }
}
function bot(setup, opts, oauthToken) {
    client.initialize(oauthToken);
    const cache = cache_1.createCache(opts.cacheRoot);
    github_1.useCache(cache);
    async function runRules() {
        const info = {};
        if (opts.kind === "single") {
            const issueOrPrRaw = await client.fetchIssue(opts.single, opts.single.id);
            const issue = github_1.Issue.fromIssueData(issueOrPrRaw);
            let pr;
            if (issueOrPrRaw.pull_request) {
                pr = await github_1.PullRequest.fromReference(opts.single, opts.single.id);
            }
            console.log(`Processing ${opts.single.owner}/${opts.single.name}#${opts.single.id}: ${issue.title}`);
            if (setup.rules.issues && !pr) {
                for (const ruleName of Object.keys(setup.rules.issues)) {
                    await runRule(issue, setup.rules.issues[ruleName], ruleName);
                }
            }
            if (setup.rules.pullRequests && pr) {
                for (const ruleName of Object.keys(setup.rules.pullRequests)) {
                    await runRule(pr, setup.rules.pullRequests[ruleName], ruleName);
                }
            }
            if (setup.rules.issuesAndPullRequests) {
                for (const ruleName of Object.keys(setup.rules.issuesAndPullRequests)) {
                    await runRule(issue, setup.rules.issuesAndPullRequests[ruleName], ruleName);
                }
            }
            await actionRunner_1.runActions(info, opts);
        }
        else if (opts.kind === "queries") {
            for (const query of opts.queries) {
                await client.runQuery(query, async (item) => {
                    await runRulesOn(item, setup);
                });
            }
            await actionRunner_1.runActions(info, opts);
        }
        else {
            throw new Error("Unreachable?");
        }
    }
    return ({
        runRules,
    });
}
exports.default = bot;
//# sourceMappingURL=index.js.map