"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function parseQuery(json) {
    if ("kind" in json) {
        const kind = json.kind;
        switch (kind) {
            case "prs":
                return parsePrsQuery(json);
            case "issues":
                throw new Error("Issue queries NYI");
            default:
                throw new Error(`Query kind '${kind}' must be "prs" or "issues"`);
        }
    }
    else {
        throw new Error('Must specify "kind" property');
    }
}
exports.parseQuery = parseQuery;
function parsePrsQuery(json) {
    const repo = getProperty(json, "repo", null, (r) => /\w+\/\w+/.test(r));
    const state = getProperty(json, "state", "open", (x) => ["open", "closed", "all"].includes(x));
    const count = getProperty(json, "count", "all", (n) => n === "all" || typeof n === "number");
    const sort = getProperty(json, "sort", "created", (x) => ["created", "updated", "popularity", "long-running"].includes(x));
    const direction = getProperty(json, "direction", "desc", (x) => ["asc", "desc"].includes(x));
    return ({
        repo,
        kind: "prs",
        state,
        count,
        sort,
        direction,
    });
}
function getProperty(json, key, defaultValue, validate) {
    if (key in json) {
        const value = json[key];
        if (!validate(value)) {
            throw new Error(`Invalid value for '${key}'`);
        }
        return value;
    }
    else {
        if (defaultValue === null) {
            throw new Error(`Must specify value for '${key}'`);
        }
        else {
            return defaultValue;
        }
    }
}
//# sourceMappingURL=query-parser.js.map