"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class WeakStringMap {
    constructor() {
        this.keys = {};
        this.map = new WeakMap();
    }
    get(s) {
        // No key by that name
        if (!this.keys[s])
            return undefined;
        const result = this.map.get(this.keys[s]);
        if (result === undefined) {
            // Object went missing from the map so delete its corresponding key
            delete this.keys[s];
        }
        return result;
    }
    delete(s) {
        if (!this.keys[s])
            return;
        this.map.delete(this.keys[s]);
        delete this.keys[s];
    }
    set(s, value) {
        this.keys[s] = this.keys[s] || {};
        this.map.set(this.keys[s], value);
        return this;
    }
}
exports.default = WeakStringMap;
//# sourceMappingURL=weak-string-map.js.map